
# Processing Python     ![](https://processing.org/favicon) 

Processing Python is a powerful and easy-to-use Graphics Library for Python based on [Processing](https://processing.org/).

It allows you to draw shapes in a window with simple functions like **rect()** or **line()**, design animations using the mouse position and much more.


## Installation


Install the processing-py package using **pip**:
```
 pip install processing-py
```

## How to use


```python
from processing_py import *

app = App(600,400) # create window: width, height
app.background(255,0,0) # set background:  red, green, blue
app.redraw() # refresh the window

app.exit() # close the window

```


## More functions

Explore all the possibilities in the [Processing Reference](https://processing.org/reference/).
